'''
anorack's private modules
'''

type(0_0)  # Python >= 3.6 is required

# vim:ts=4 sts=4 sw=4 et
